==> 3abn-2.1.2.tgz: package/lib/index.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Player = require("player"),
    ul = require("ul"),
    scrapeIt = require("scrape-it"),
    Daty = require("daty"),
    EventEmitter = require("events"),
    PageChanged = require("page-changed"),
    htmlDecoder = require("html-encoder-decoder"),
    noop = require("noop6"),
    abs = require("abs"),
    fs = require("fs");

// Constants
var PLAY_URL = "http://war.str3am.com:7180/MC01",
    PLAYLIST_URL = "http://3abn.biz/RDO-MC_Playlist.htm"
//, PLAYLIST_URL = "https://urlreq.appspot.com/req?method=GET&url=http%3A%2F%2F3abn.biz%2FRDO-MC_Playlist.htm&Content-Type=text%2Fplain"
;

var ThreeAbn = function (_Player) {
    _inherits(ThreeAbn, _Player);

    /**
     * threeAbn
     * Streams audio from `3abn.org`.
     *
     * @name threeAbn
     * @function
     * @param {Object} options An object containing the following fields:
     *
     *  - `autoplay` (Boolean): Autoplays the radio (default: `true`).
     *  - `favorites_path` (String): The favorite songs file path (default: `~/3abn-favorites`).
     *
     * @return {Player} The `Player` instance (see the `player` npm package).
     */

    function ThreeAbn(options) {
        _classCallCheck(this, ThreeAbn);

        var _this = _possibleConstructorReturn(this, Object.getPrototypeOf(ThreeAbn).call(this, PLAY_URL));

        options = _this.abn_options = ul.merge(options, {
            autoplay: true,
            favorites_path: abs("~/3abn-favorites")
        });

        _this.on("playing", function () {
            _this.is_playing = true;
        });

        _this.enable("stream");
        if (options.autoplay) {
            _this.play();
        }

        new PageChanged(PLAYLIST_URL, function (err, body) {
            if (err) {
                return _this.emit("song_changed_changed", err);
            }
            ThreeAbn.playlistInfo(body, function (err, data) {
                if (err) {
                    return _this.emit("song_changed_changed", err);
                }
                _this.songInfo = data;
                _this.liked_current_song = false;
                _this.emit("song_changed", err, data.playing, data);
            });
        });

        _this.songInfo = null;
        return _this;
    }

    /**
     * playlistInfo
     * Get the playlist information.
     *
     * @name playlistInfo
     * @function
     * @param {Function} cb The callback function.
     */


    _createClass(ThreeAbn, [{
        key: "likeCurrentSong",


        /**
         * likeCurrentSong
         * Stores the current song name in the favorites list.
         *
         * @name likeCurrentSong
         * @function
         * @param {Function} cb The callback function.
         */
        value: function likeCurrentSong(cb) {
            cb = cb || noop;
            if (this.liked_current_song) {
                return cb(null, null, false);
            }
            if (!this.songInfo) {
                return cb(new Error("Missing the song information."));
            }
            this.liked_current_song = true;
            this.emit("liked_current");
            fs.appendFile(this.abn_options.favorites_path, this.songInfo.playing + "\n", cb);
        }
    }], [{
        key: "playlistInfo",
        value: function playlistInfo(html, cb) {
            var scrapingInfo = {
                playing: {
                    selector: "table td",
                    eq: 1
                },
                playlist: {
                    selector: "table td",
                    eq: 3,
                    how: "html",
                    convert: function convert(html) {
                        html = htmlDecoder.decode(html);
                        return html.split("<br>").slice(0, -1).map(function (c) {
                            var s = c.split(" - "),
                                rawTime = s[0].slice(0, -2),
                                isPM = s[0].slice(-2) === "pm",
                                timeSplits = rawTime.split(":"),
                                hours = +timeSplits[0] + (isPM ? 12 : 0),
                                minutes = +timeSplits[1],
                                dat = new Daty();

                            // 5 is the timezone offset
                            dat.setUTCHours(hours + 5);
                            dat.setUTCMinutes(minutes);

                            return {
                                title: s.slice(1).join(" - "),
                                song_name: s[2],
                                artist: s[1],
                                raw_time: s[0],
                                date: dat
                            };
                        });
                    }
                }
            };

            if (html) {
                return cb(null, scrapeIt.scrapeHTML(html, scrapingInfo));
            }

            return scrapeIt(PLAYLIST_URL, scrapingInfo, html);
        }
    }]);

    return ThreeAbn;
}(Player);

module.exports = ThreeAbn;

==> 3abn-2.1.4.tgz: package/lib/index.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Player = require("player"),
    ul = require("ul"),
    scrapeIt = require("scrape-it"),
    Daty = require("daty"),
    EventEmitter = require("events"),
    PageChanged = require("page-changed"),
    htmlDecoder = require("html-encoder-decoder"),
    noop = require("noop6"),
    abs = require("abs"),
    fs = require("fs");

// Constants
var PLAY_URL = "http://war.str3am.com:7180/MC01",
    PLAYLIST_URL = "http://3abn.biz/RDO-MC_Playlist.htm"
//, PLAYLIST_URL = "https://urlreq.appspot.com/req?method=GET&url=http%3A%2F%2F3abn.biz%2FRDO-MC_Playlist.htm&Content-Type=text%2Fplain"
;

var ThreeAbn = function (_Player) {
    _inherits(ThreeAbn, _Player);

    /**
     * threeAbn
     * Streams audio from `3abn.org`.
     *
     * @name threeAbn
     * @function
     * @param {Object} options An object containing the following fields:
     *
     *  - `autoplay` (Boolean): Autoplays the radio (default: `true`).
     *  - `favorites_path` (String): The favorite songs file path (default: `~/3abn-favorites`).
     *
     * @return {Player} The `Player` instance (see the `player` npm package).
     */
    function ThreeAbn(options) {
        _classCallCheck(this, ThreeAbn);

        var _this = _possibleConstructorReturn(this, (ThreeAbn.__proto__ || Object.getPrototypeOf(ThreeAbn)).call(this, PLAY_URL));

        options = _this.abn_options = ul.merge(options, {
            autoplay: true,
            favorites_path: abs("~/3abn-favorites")
        });

        _this.on("playing", function () {
            _this.is_playing = true;
        });

        _this.enable("stream");
        if (options.autoplay) {
            _this.play();
        }

        new PageChanged(PLAYLIST_URL, function (err, body) {
            if (err) {
                return _this.emit("song_changed_changed", err);
            }
            ThreeAbn.playlistInfo(body, function (err, data) {
                if (err) {
                    return _this.emit("song_changed_changed", err);
                }
                _this.songInfo = data;
                _this.liked_current_song = false;
                _this.emit("song_changed", err, data.playing, data);
            });
        });

        _this.songInfo = null;
        return _this;
    }

    /**
     * playlistInfo
     * Get the playlist information.
     *
     * @name playlistInfo
     * @function
     * @param {Function} cb The callback function.
     */


    _createClass(ThreeAbn, [{
        key: "likeCurrentSong",


        /**
         * likeCurrentSong
         * Stores the current song name in the favorites list.
         *
         * @name likeCurrentSong
         * @function
         * @param {Function} cb The callback function.
         */
        value: function likeCurrentSong(cb) {
            cb = cb || noop;
            if (this.liked_current_song) {
                return cb(null, null, false);
            }
            if (!this.songInfo) {
                return cb(new Error("Missing the song information."));
            }
            this.liked_current_song = true;
            this.emit("liked_current");
            fs.appendFile(this.abn_options.favorites_path, this.songInfo.playing + "\n", cb);
        }
    }], [{
        key: "playlistInfo",
        value: function playlistInfo(html, cb) {
            var scrapingInfo = {
                playing: {
                    selector: "table td",
                    eq: 1
                },
                playlist: {
                    selector: "table td",
                    eq: 3,
                    how: "html",
                    convert: function convert(html) {
                        html = htmlDecoder.decode(html);
                        return html.split("<br>").slice(0, -1).map(function (c) {
                            var s = c.split(" - "),
                                rawTime = s[0].slice(0, -2),
                                isPM = s[0].slice(-2) === "pm",
                                timeSplits = rawTime.split(":"),
                                hours = +timeSplits[0] + (isPM ? 12 : 0),
                                minutes = +timeSplits[1],
                                dat = new Daty();

                            // 5 is the timezone offset
                            dat.setUTCHours(hours + 5);
                            dat.setUTCMinutes(minutes);

                            return {
                                title: s.slice(1).join(" - "),
                                song_name: s[2],
                                artist: s[1],
                                raw_time: s[0],
                                date: dat
                            };
                        });
                    }
                }
            };

            if (html) {
                return cb(null, scrapeIt.scrapeHTML(html, scrapingInfo));
            }

            return scrapeIt(PLAYLIST_URL, scrapingInfo, html);
        }
    }]);

    return ThreeAbn;
}(Player);

module.exports = ThreeAbn;
